
0.4.13 (2016-12-12)
###################

Changes since 0.4.12 (2016-12-06).

Bug Fixes
$$$$$$$$$

* closes `#390 <https://github.com/biocommons/hgvs/issues/390/>`_: fix missing HGVSError import in variantmapper [`BROKEN: 9e3bee72a349 <https://github.com/biocommons/hgvs/commit/9e3bee72a349>`_]
